# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0-alpha.2](https://github.com/lox-space/lox/compare/lox-earth-v0.1.0-alpha.1...lox-earth-v0.1.0-alpha.2) - 2024-12-18

### Other

- implement dynamic origin and frame types

## [0.1.0-alpha.1](https://github.com/lox-space/lox/compare/lox-earth-v0.1.0-alpha.0...lox-earth-v0.1.0-alpha.1) - 2024-11-12

### Other

- updated the following local packages: lox-bodies, lox-math, lox-io, lox-time

## [0.1.0-alpha.0](https://github.com/lox-space/lox/releases/tag/lox-earth-v0.1.0-alpha.0) - 2024-07-19

### Other
- Rename lox-utils to lox-math because the former is taken ([#146](https://github.com/lox-space/lox/pull/146))
- Add crate descriptions ([#145](https://github.com/lox-space/lox/pull/145))
- Align versions ([#143](https://github.com/lox-space/lox/pull/143))
- Release preparation ([#140](https://github.com/lox-space/lox/pull/140))
- Implement `DeltaUt1Tai` provider ([#101](https://github.com/lox-space/lox/pull/101))
- Split up `lox-eop` ([#100](https://github.com/lox-space/lox/pull/100))
- Align casing of types with Rust API guidelines ([#86](https://github.com/lox-space/lox/pull/86))
- Hoist shared constants and type aliases ([#84](https://github.com/lox-space/lox/pull/84))
- Replace lox_time::continuous with smaller top-level modules ([#72](https://github.com/lox-space/lox/pull/72))
- Core No More ([#68](https://github.com/lox-space/lox/pull/68))
